@@ -86,13 +86,15 @@ class FeatureGenerator:
     def transform(self,fields_json):
         feature = []
         for field_name in self.fields:
+            # 默认值
+            if self.auto_fill_missing:
+                _missing = self.woe_defalut.get(field_name)
+            else:
+                _missing = self.missing
             # 取数据
             field_value = fields_json.get(field_name)
             if not field_value:
-                if self.auto_fill_missing:
-                    feature.append(self.woe_defalut.get(field_name))
-                else:
-                    feature.append(self.missing)
+                feature.append(_missing)
                 continue
             # 类别编码
             cate_coder = self.cate_coder_dict.get(field_name)
@@ -106,7 +108,12 @@ class FeatureGenerator:
             woe = self.woe_dict.get(field_name)
             if woe:
                 field_value = woe.transform(field_value)
+                if not field_value:
+                    field_value = _missing
+            else:
+                field_value = _missing
             feature.append(field_value)
+
         return [feature]
 
     def preprocessing(self, df_fields):
@@ -129,8 +136,8 @@ if __name__ == '__main__':
     df.columns = ['field1', 'field2', 'label']
     df_fields, df_label = df[['field1', 'field2']], df['label']
 
-    feature_generator = FeatureGenerator(auto_fill_missing=True)
-    aa=feature_generator.fit_transform(df_fields,df_label,category_fields=['field1'])
+    feature_generator = FeatureGenerator()
+    feature_generator.fit_transform(df_fields,df_label,category_fields=['field1'])
     print(feature_generator.cate_fields_info)
     print(feature_generator.binning_woe_info)
 
@@ -139,7 +146,7 @@ if __name__ == '__main__':
     #
     # # load
     # feature_generator= pickle.load(open(file_name, "rb"))
-    fields_json = {'field1':4, 'field232':5, 'aa':9}
+    fields_json = {'field1':4, 'field22':5, 'aa':9}
     feature = feature_generator.transform(fields_json)
     print(feature)
 
